@@ -1,10 +1,10 @@
 #!perl -T
 use strict;
 use warnings FATAL => 'all';
-use Test::More tests => 12;
+use Test::More tests => 13;
 
 BEGIN {
-    use_ok( 'MarpaX::RFC::RFC3986' ) || print "Bail out!\n";
+    use_ok( 'MarpaX::RFC::RFC3987' ) || print "Bail out!\n";
 }
 
 our @URI = (
@@ -18,9 +18,10 @@ our @URI = (
             "telnet://192.0.2.16:80/",
             "urn:oasis:names:specification:docbook:dtd:xml:4.1.2",
             "foo://example.com:8042/over/there?name=ferret#nose",
-            "urn:example:animal:ferret:nose"
+            "urn:example:animal:ferret:nose",
+            "http://\x{7D0D}\x{8C46}.example.org/%E2%80%AE"
            );
 
 foreach (@URI) {
-  ok(MarpaX::RFC::RFC3986->new($_)->is_absolute, $_);
+  ok(MarpaX::RFC::RFC3987->new($_)->is_absolute, $_);
 }
